[yt-svn] commit/yt: ngoldbaum: Improving the language in the install script.

Bitbucket commits-noreply at bitbucket.org
Tue Feb 5 22:52:58 PST 2013


1 new commit in yt:

https://bitbucket.org/yt_analysis/yt/commits/d6fe5086342e/
changeset:   d6fe5086342e
branch:      yt
user:        ngoldbaum
date:        2013-02-06 07:51:18
summary:     Improving the language in the install script.
affected #:  1 file

diff -r c57b08a8a710c0fab9b5b8da6bb550f65b8177a4 -r d6fe5086342edfa314a842ec8291055c672a01b6 doc/install_script.sh
--- a/doc/install_script.sh
+++ b/doc/install_script.sh
@@ -8,7 +8,7 @@
 # that's the next one, DEST_DIR.  But, if you want to use an existing HDF5
 # installation you can set HDF5_DIR, or if you want to use some other
 # subversion checkout of YT, you can set YT_DIR, too.  (It'll already
-# check the current directory and one up.
+# check the current directory and one up).
 #
 # And, feel free to drop me a line: matthewturk at gmail.com
 #
@@ -26,7 +26,7 @@
 # and install it on its own
 #HDF5_DIR=
 
 # If you need to supply arguments to the NumPy and scipy build, supply them here
 # This one turns on gfortran manually:
 #NUMPY_ARGS="--fcompiler=gnu95"
 # If you absolutely can't get the fortran to work, try this:
@@ -183,7 +183,7 @@
 	echo "download link."
 	echo 
 	echo "We have gathered some additional instructions for each"
-	echo "version of OS X below. If you have trouble setting up Xcode"
+	echo "version of OS X below. If you have trouble installing yt"
 	echo "after following these instructions, don't hesitate to contact"
 	echo "the yt user's e-mail list."
 	echo
@@ -222,10 +222,6 @@
         echo
         echo "$ export CC=gcc-4.2"
         echo "$ export CXX=g++-4.2"
-        echo
-	echo "If the installation fails with these environment variables"
-	echo "set, don't hesitate to ask for help on the yt user's mailing"
-	echo "list."
 	echo
         OSX_VERSION=`sw_vers -productVersion`
         if [ "${OSX_VERSION##10.8}" != "${OSX_VERSION}" ]
@@ -268,11 +264,12 @@
     if [$INST_SCIPY -eq 1]
     then
 	echo
-	echo "Looks like you've requested that the install script build scipy."
+	echo "Looks like you've requested that the install script build SciPy."
 	echo
-	echo "If the scipy build fails, please uncomment the line at the top of"
-	echo "the install script that sets NUMPY_ARGS, delete any broken"
-	echo "installation tree, and re-run the install script verbatim."
+	echo "If the SciPy build fails, please uncomment one of the the lines"
+	echo "at the top of the install script that sets NUMPY_ARGS, delete"
+	echo "any broken installation tree, and re-run the install script"
+	echo "verbatim."
 	echo
 	echo "If that doesn't work, don't hesitate to ask for help on the yt"
 	echo "user's mailing list."
@@ -26,7 +26,7 @@
 #HDF5_DIR=
 
-# If you need to supply arguments to the NumPy and scipy build, supply them here
+# If you need to supply arguments to the NumPy or SciPy build, supply them here
 # This one turns on gfortran manually:
 #NUMPY_ARGS="--fcompiler=gnu95"

Repository URL: https://bitbucket.org/yt_analysis/yt/

--

This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.



More information about the yt-svn mailing list